@@ -67,7 +67,7 @@ See also https://www.sphinx-doc.org/en/master/usage/extensions/autodoc.html
 
 # stdlib
 import sys
-from typing import Any, Callable, Dict, List, Optional, Tuple
+from typing import Any, Callable, Dict, List, Tuple
 
 # 3rd party
 from sphinx.application import Sphinx
@@ -79,7 +79,7 @@ from sphinx.util.inspect import getdoc, safe_getattr
 
 # this package
 from sphinx_toolbox import __version__
-from sphinx_toolbox.more_autodoc.utils import begin_generate, filter_members_warning
+from sphinx_toolbox.more_autodoc.utils import filter_members_warning
 
 if sys.version_info < (3, 8):  # pragma: no cover (>=py38)
 	# 3rd party
@@ -121,6 +121,11 @@ globally_excluded_methods = {
 		"__tree_hash__",
 		}
 
+runtime_message = (
+		"This protocol is `runtime checkable "
+		"<https://www.python.org/dev/peps/pep-0544/#runtime-checkable-decorator-and-narrowing-types-by-isinstance>`_."
+		)
+
 
 class ProtocolDocumenter(ClassDocumenter):
 	r"""
@@ -128,14 +133,14 @@ class ProtocolDocumenter(ClassDocumenter):
 	for documenting :class:`typing.Protocol`\s.
 
 	.. versionadded:: 0.2.0
-	"""
+	"""  # noqa D400
 
 	objtype = "protocol"
 	directivetype = "protocol"
 	priority = 20
 	option_spec: Dict[str, Callable] = {
-			'noindex': bool_option,
-			'member-order': member_order_option,
+			"noindex": bool_option,
+			"member-order": member_order_option,
 			}
 
 	@classmethod
@@ -159,61 +164,37 @@ class ProtocolDocumenter(ClassDocumenter):
 
 		return ''  # pragma: no cover
 
-	def generate(
-			self,
-			more_content: Optional[Any] = None,
-			real_modname: Optional[str] = None,
-			check_module: bool = False,
-			all_members: bool = False,
-			) -> None:
+	def add_content(self, more_content: Any, no_docstring: bool = False):
 		"""
-		Generate reST for the object given by ``self.name``, and possibly for its members.
+		Add the autodocumenter content.
 
-		:param more_content: Additional content to include in the reST output.
-		:param real_modname: Module name to use to find attribute documentation.
-		:param check_module: If :py:obj:`True`, only generate if the object is defined
-			in the module name it is imported from.
-		:param all_members: If :py:obj:`True`, document all members.
+		:param more_content:
+		:param no_docstring:
 		"""
 
-		ret = begin_generate(self, real_modname, check_module)
-		if ret is None:
-			return
-		sourcename = ret
+		super().add_content(more_content=more_content, no_docstring=no_docstring)
 
-		# make sure that the result starts with an empty line.  This is
-		# necessary for some situations where another directive preprocesses
-		# reST and no starting newline is present
-		self.add_line('', sourcename)
-
-		# generate the directive header and options, if applicable
-		self.add_directive_header('')
-		self.add_line('', sourcename)
-
-		# e.g. the module directive doesn't have content
-		self.indent += self.content_indent
-
-		# add all content (from docstrings, attribute docs etc.)
-		self.add_content(more_content)
+		sourcename = self.get_sourcename()
 
 		if not getdoc(self.object):
 			self.add_line(":class:`typing.Protocol`.", sourcename)
 			self.add_line('', sourcename)
 
 		if hasattr(self.object, "_is_runtime_protocol") and self.object._is_runtime_protocol:
-			self.add_line(
-					"This protocol is `runtime checkable <https://www.python.org/dev/peps/pep-0544/#runtime-checkable-decorator-and-narrowing-types-by-isinstance>`_.",
-					sourcename
-					)
+			self.add_line(runtime_message, sourcename)
 			self.add_line('', sourcename)
 
 		self.add_line("Classes that implement this protocol must have the following methods:", sourcename)
 		self.add_line('', sourcename)
 
-		# document members, if possible
-		# self.options.special_members = []
-		# self.options.undoc_members = []
-		self.document_members(True)
+	def document_members(self, all_members: bool = False) -> None:
+		"""
+		Generate reST for member documentation.
+
+		All members are always documented.
+		"""
+
+		super().document_members(True)
 
 	def filter_members(
 			self,
